@@ -1,4 +1,7 @@
-#' Monthly data
+#' @title KMS Monthly data
+#'
+#' @description The dataset that was used in Kostakis et al (2015), containing
+#'a range of financial variables.
 #'
 #' \itemize{
 #'  \item Date: year-month-date (monthly frequency)
@@ -19,10 +22,14 @@
 #' @format A data.frame with 13 variables and 1,033 observations.
 #'
 #' @source \url{https://drive.google.com/open?id=1FdT2STHO2Lnlweom4AwICVf-rpVMfgV4}
-#' @importFrom tibble tibble
-"monthly"
+"kms"
 
-#' Quarterly data
+
+
+#' @title KMS Quarterly data
+#'
+#' @description The dataset that was used in Kostakis et al (2015), containing
+#'a range of financial variables.
 #'
 #' \itemize{
 #'  \item Date: year-month-date
@@ -40,9 +47,28 @@
 #'	\item Ret: S&P 500 value-weighted log excess returns
 #'}
 #'
+#'
 #' @format A data.frame with 13 variables and 345 observations.
 #'
 #' @source \url{https://drive.google.com/open?id=1FdT2STHO2Lnlweom4AwICVf-rpVMfgV4}
-#' @importFrom tibble tibble
+"kms_quarterly"
+
+#' @title YLPC Quarterly data
+#'
+#' @description The dataset that was used in ..., containing
+#'a range of  variables.
+#'
+#' @source \url{https://www.tandfonline.com/doi/suppl/10.1080/01621459.2019.1686392/suppl_file/uasa_a_1686392_sm7226.zip}
+#'
+"ylpc"
+
+#' Monthly dataset of KMS
+#'
+#' @keywords internal
+"monthly"
+
+#' Quarterly dataset of KMS
+#'
+#' @keywords internal
 "quarterly"
 
